Green
=====

Green is a clean, colorful, fast python test runner.

Documentation
-------------

For full documentation please visit the `Github page for Green`_, or subscribe
to `Python Testing with Green`_ on Udemy.  You can find discounts for the Udemy
course in the documentation on Github.

Features
--------

- **Clean** - Low redundancy in output. Result statistics for each test is vertically aligned.
- **Colorful** - Terminal output makes good use of color when the terminal supports it.
- **Fast** - Tests run in independent processes.  (One per processor by default.  Does not play nicely with gevent.)
- **Powerful** - Multi-target + auto-discovery.
- **Traditional** - Use the normal ``unittest`` classes and methods for your unit tests.
- **Descriptive** - Multiple verbosity levels, from just dots to full docstring output.
- **Convenient** - Bash-completion and ZSH-completion of options and test targets.
- **Thorough** - Built-in, optional integration with `coverage`_
- **Modern** - Supports Python 2.7, and 3.4+.  Additionally, `PyPy` is supported on a best-effort basis.
- **Portable** - macOS, Linux, and BSDs are fully supported.  Windows is supported on a best-effort basis.
- **Living** - This project grows and changes.  See the `changelog`_

.. _Github page for Green: https://github.com/CleanCut/green#green
.. _Python Testing with Green: https://www.udemy.com/python-testing-with-green/?couponCode=GREEN_ANGEL
.. _coverage: http://nedbatchelder.com/code/coverage/
.. _PyPy: http://pypy.org
.. _changelog: https://github.com/CleanCut/green/blob/master/CHANGELOG.md
